#' Matrix of predicted alpha diversity in each cell.
#'
#' @format vector.
"alpha_list"

#' Total (estimated) species in the system.
#'
#' @format numeric
"estimated_gamma"

#' Pairwise matrix of species in common.
#'
#' @format matrix
"target_matrix"

#' List with example data created using the \code{gdm} package
#'
#' @format list
"minimal_example_data"